package com.yl8timer.kqj.yl8timer.ctrl;

import java.text.DateFormat;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Date;

import org.springframework.beans.factory.annotation.Value;
import org.springframework.context.annotation.Configuration;
import org.springframework.scheduling.annotation.EnableScheduling;
import org.springframework.scheduling.annotation.Scheduled;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.yl8timer.kqj.yl8timer.entity.fk.FkData;
import com.yl8timer.kqj.yl8timer.entity.fk.FkHsRequest;
import com.yl8timer.kqj.yl8timer.entity.fk.FkHsResponse;

@Configuration // 1.主要用于标记配置类，兼备Component的效果。
@EnableScheduling // 2.开启定时任务
public class CleaningIntervalController {
	
	@Value("${config.cleaning-interval}")
	private Integer cleaninginterval;

	/**
	 * 	每天凌晨4点 删除前30天数据
	 */
	@Scheduled(cron = "0 0 4 * * ?")//每天凌晨4点
	public void datadump() {
		
		String str = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").format(new Date()).toString();//
		String front = requires_extra_times(str,-cleaninginterval,3,2);//前30天的开头
		
		FkData.builder().build().delete(new QueryWrapper<FkData>().lambda().le(FkData::getIoTime, front));
		
		FkHsRequest.builder().build().delete(new QueryWrapper<FkHsRequest>().lambda().le(FkHsRequest::getTime, front));
		
		FkHsResponse.builder().build().delete(new QueryWrapper<FkHsResponse>().lambda().le(FkHsResponse::getTime, front));
	}
	
	
	/**
	 * @param timeStr 修改的时间
	 * @param num 修改数字
	 * @param numtime
	 * @return 1：增加一年、2：增加一天、3：减10天、4：增加一个月
	 */
	public static String requires_extra_times(String timeStr, int num,int numtime,int daft) {
		
		DateFormat df;
		if(daft == 1) {
			df = new SimpleDateFormat("yyyy-MM-dd");
		}else {
			df = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
		}
		
		Date date = null;
		try {
			date = df.parse(timeStr);
		} catch (ParseException e) {
			e.printStackTrace();
		}
		
		Calendar cal = Calendar.getInstance();
		cal.setTime(date);// 设置起时间
		if(numtime == 1) {
			cal.add(Calendar.YEAR, num);// 增加一年
		}else if(numtime == 2) {
			cal.add(Calendar.DATE, num);//增加一天
		}else if(numtime == 3) {
			cal.add(Calendar.DATE, num);//减10天
		}else if(numtime == 4){
			cal.add(Calendar.MONTH, num);//增加一个月
		}else if(numtime == 5) {
			cal.add(Calendar.HOUR, num);
		}
		return df.format(cal.getTime());
	}
}
