/**  
* <p>Title: SetUsersController.java</p>  
* <p>Description: </p>  
* @author dsc  
* @date 2020年5月14日  
* @version 1.0  
*/
package com.yl8timer.kqj.yl8timer.ctrl;

import java.util.Date;
import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.scheduling.annotation.SchedulingConfigurer;
import org.springframework.scheduling.config.ScheduledTaskRegistrar;
import org.springframework.scheduling.support.CronTrigger;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.yl8timer.kqj.yl8timer.entity.fk.FkHsRequest;
import com.yl8timer.kqj.yl8timer.entity.fk.FkHsResponse;
import com.yl8timer.kqj.yl8timer.entity.fk.FkTask;
import com.yl8timer.kqj.yl8timer.entity.fk.FkTaskRelation;
import com.yl8timer.kqj.yl8timer.tools.HSTools;

import cn.hutool.core.date.DateUnit;
import cn.hutool.core.date.DateUtil;

/**
 * <p>
 * Title: SetUsersController.java
 * </p>
 * <p>
 * Description:
 * </p>
 * 
 * @author dsc
 * @date 2020年5月14日
 * @version 1.0
 */
@Component
public class SetUsersController implements SchedulingConfigurer {

	@Value("${config.ontime.cron}")
	private String cron;

	@Value("${config.ontime.overtime}")
	private Integer overtime;

	@Autowired
	private HSTools hsTools;

	// 数据库动态更改定时配置
	@Override
	public void configureTasks(ScheduledTaskRegistrar taskRegistrar) {
		taskRegistrar.addTriggerTask(() -> {
			// 任务逻辑
			setUsersInfo();
			updateStatus();
		}, triggerContext -> {
			CronTrigger cronTrigger = new CronTrigger(cron); // cron配置
			return cronTrigger.nextExecutionTime(triggerContext); // 下次执行任务的时间
		});
	}

	/**
	 * 同步到新设备
	 */
	@Transactional
	private void setUsersInfo() {
		List<FkTask> list = FkTask.builder().build()
				.selectList(new LambdaQueryWrapper<FkTask>().eq(FkTask::getStatus, 1)); // 查询待执行任务

		Integer taskID = null;

		for (FkTask fkTask : list) { // 遍历待执行任务

			taskID = fkTask.getId(); // 任务id

			List<FkTaskRelation> fkTaskRelations = FkTaskRelation.builder().build()
					.selectList(new LambdaQueryWrapper<FkTaskRelation>().eq(FkTaskRelation::getTaskId, taskID));
			String setTransId = null;

			for (FkTaskRelation fkTaskRelation : fkTaskRelations) {
				setTransId = fkTaskRelation.getSetTransId();

				String getTransId = fkTaskRelation.getGetTransId(); // get标识

				FkHsRequest fkHsRequest = FkHsRequest.builder().build()
						.selectOne(new LambdaQueryWrapper<FkHsRequest>().eq(FkHsRequest::getId, getTransId)); // 通过get标识查询请求状态
				FkHsResponse fkHsResponse = FkHsResponse.builder().build()
						.selectOne(new LambdaQueryWrapper<FkHsResponse>().eq(FkHsResponse::getTransId, getTransId)); // 通过get标识查询响应状态

				if (fkHsRequest.getStatus() != null) {
					try {
						if (setTransId == null) {
							setTransId = hsTools.setUserInfo(fkTask.getNewDevId(), fkHsResponse.getTotalByte()); // 导入数据响应的transId
						}
						fkTaskRelation.setSetTransId(setTransId);
						fkTaskRelation.insertOrUpdate();
					} catch (Exception e) {
						Logoutput("请确认考勤机连接状态");
						e.getStackTrace();
					}
				}

			}

		}

	}

	private void updateStatus() {
		List<FkTask> list = FkTask.builder().build()
				.selectList(new LambdaQueryWrapper<FkTask>().eq(FkTask::getStatus, 1)); // 查询待执行任务
		for (FkTask fkTask : list) {
			long minute = DateUtil.between(fkTask.getCreatedTime(), new Date(), DateUnit.MINUTE, true);
			if (minute > overtime) {
				fkTask.setStatus(3);
				fkTask.setSuccessTime(new Date());
				fkTask.insertOrUpdate();
			}

			Integer count = 0;
			Integer taskId = fkTask.getId();
			List<FkTaskRelation> fkTaskRelations = FkTaskRelation.builder().build()
					.selectList(new LambdaQueryWrapper<FkTaskRelation>().eq(FkTaskRelation::getTaskId, taskId));
			for (FkTaskRelation fkTaskRelation : fkTaskRelations) {
				String setTransId = fkTaskRelation.getSetTransId();

				FkHsRequest fkHsRequest = FkHsRequest.builder().build().selectOne(new LambdaQueryWrapper<FkHsRequest>()
						.eq(FkHsRequest::getId, setTransId).eq(FkHsRequest::getStatus, "OK"));
				if (fkHsRequest != null) {
					count++;
				}
			}
			Logoutput(String.valueOf(count));
			Logoutput(String.valueOf(fkTaskRelations.size()));
			if (count == fkTaskRelations.size()) {
				fkTask.setStatus(2);
				fkTask.setSuccessTime(new Date());
				fkTask.insertOrUpdate();
			}

		}

	}
	
	@Value("${config.environmental-science}")
	public String environmental_science;
	
	public void Logoutput(String science) {
		
		if(!("pro").equals(environmental_science)) {
			
			System.out.println(science);
		}else {
			System.out.println("");
		}
		
	}

}