package com.yl8timer.kqj.yl8timer.ctrl;

import java.util.List;

import org.springframework.beans.factory.annotation.Value;
import org.springframework.http.HttpEntity;
import org.springframework.http.HttpHeaders;
import org.springframework.http.ResponseEntity;
import org.springframework.scheduling.annotation.SchedulingConfigurer;
import org.springframework.scheduling.config.ScheduledTaskRegistrar;
import org.springframework.scheduling.support.CronTrigger;
import org.springframework.stereotype.Component;
import org.springframework.util.LinkedMultiValueMap;
import org.springframework.util.MultiValueMap;
import org.springframework.web.client.RestTemplate;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.yl8timer.kqj.yl8timer.entity.fk.FkData;

import cn.hutool.json.JSONObject;
import cn.hutool.json.JSONUtil;

/**
 * Title: retryUtil.java Description: 重试机制-配置yml固定时间扫描是否有未转发成功的数据 上限10次
 * 
 * @author dsc
 * @date 2020年5月12日
 * @version 1.0
 */
@Component
public class retryController implements SchedulingConfigurer {

	@Value("${config.retry.cron}")
	private String cron;

	// 数据库动态更改定时配置
	@Override
	public void configureTasks(ScheduledTaskRegistrar taskRegistrar) {
		taskRegistrar.addTriggerTask(() -> {
			// 任务逻辑
			retry();
		}, triggerContext -> {
			CronTrigger cronTrigger = new CronTrigger(cron); // cron配置 30min/次
			return cronTrigger.nextExecutionTime(triggerContext); // 下次执行任务的时间
		});
	}

	/**
	 * 重试转发数据
	 */
	private void retry() {

		List<FkData> fkDataList = FkData.builder().build()
				.selectList(new LambdaQueryWrapper<FkData>().eq(FkData::getIsSuccess, 0).lt(FkData::getTimes, 10));
		for (FkData fkData : fkDataList) {
			// 封装json对象
			JSONObject vResultJson = new JSONObject();
			vResultJson.put("dev_id", fkData.getDevId());
			vResultJson.put("user_id", fkData.getUserId());
			vResultJson.put("verify_mode", fkData.getVerifyMode());
			vResultJson.put("io_time", fkData.getIoTime());
			String sFinal = vResultJson.toString();
			JSONObject jsonObject = null;
			try {
				// 封装http请求
				HttpHeaders headers = new HttpHeaders();
				MultiValueMap<String, Object> params = new LinkedMultiValueMap<>();
				params.add("json", sFinal);
				RestTemplate restTemplate = new RestTemplate();
				HttpEntity<MultiValueMap<String, Object>> httpEntity = new HttpEntity<MultiValueMap<String, Object>>(
						params, headers);
				ResponseEntity<String> request = restTemplate.postForEntity(fkData.getUrl(), httpEntity, String.class);

				jsonObject = JSONUtil.parseObj(request.getBody()); // 封装为json对象

			} catch (Exception e) {
				fkData.setResultDetail("请求地址不存在或目标服务器未开启");
				e.getStackTrace();
			} finally {
				if (jsonObject != null) {
					fkData.setResultDetail(jsonObject.toString()); // 请求结果json对象字符串
					if (jsonObject.getStr("code").equals("200")) {
						fkData.setIsSuccess(1);
					}
				}
				Integer times = fkData.getTimes();
				times++;
				fkData.setTimes(times); // 更新请求次数
				fkData.insertOrUpdate();
			}

		}

	}

}